@@ -63,7 +63,7 @@ def test_reaction_enthalpy_balance():
     H0 = feed.Hnet - Methane.Cn.g.T_dependent_property_integral(Tref, Tb) - 2 * O2.Cn.g.T_dependent_property_integral(Tref, Tb) 
     combustion(feed)
     Hf = feed.Hnet - 2 * H2O.Cn.l.T_dependent_property_integral(Tref, Tb) - CO2.Cn.g.T_dependent_property_integral(Tref, Tb)
-    assert_allclose(Hf - H0, Methane.LHV)
+    assert_allclose(Hf - H0, -Methane.LHV)
     
     # Electrolysis of water; ensure heat of reaction without sensible
     # heats is the higher heating value of hydrogen (with opposite sign)
@@ -74,7 +74,7 @@ def test_reaction_enthalpy_balance():
     feed.phases = ('g', 'l') # Gas and liquid phases must be available
     reaction(feed) # Call to run reaction on molar flow
     Hf = feed.Hnet
-    assert_allclose(Hf - H0, -H2.HHV)
+    assert_allclose(Hf - H0, H2.HHV)
     
     # Electrolysis of water; ensure gas phase heat of reaction without sensible
     # heats is the lower heating value of hydrogen (with opposite sign)
@@ -83,7 +83,7 @@ def test_reaction_enthalpy_balance():
     H0 = feed.Hnet - H2O.Cn.l.T_dependent_property_integral(Tref, H2O.Tb) - H2O.Cn.g.T_dependent_property_integral(H2O.Tb, Tref)
     reaction(feed) # Call to run reaction on molar flow
     Hf = feed.Hnet
-    assert_allclose(Hf - H0, -H2.LHV)
+    assert_allclose(Hf - H0, H2.LHV)
     
 def test_repr():
     cal2joule = 4.184
