@@ -28,15 +28,16 @@
 # del use_numba_chemicals
 from . import thermo
 del thermo
-from . import (constants,
-               base,
-               utils,
-               chemicals,
-               exceptions,
-               functional,
-               units_of_measure,
-               separations,
-               functors,
+from . import (
+    constants,
+    base,
+    utils,
+    chemicals,
+    exceptions,
+    functional,
+    units_of_measure,
+    separations,
+    functors,
 )
 from ._chemical_data import ChemicalData
 from ._chemical import Chemical
@@ -84,4 +85,4 @@ pd.set_option('display.max_columns', 10)
 pd.set_option('max_colwidth', 35)
 del np, pd
 
-__version__ = "0.28.3"
+__version__ = "0.28.6"
