@@ -11,13 +11,12 @@ from . import utils
 from .exceptions import UndefinedChemical
 from ._chemical import Chemical
 from .indexer import ChemicalIndexer, SplitIndexer
-from collections.abc import Iterable
 import thermosteam as tmo
 import numpy as np
 
 __all__ = ('Chemicals', 'CompiledChemicals')
 setattr = object.__setattr__
-
+    
 # %% Functions
 
 def must_compile(*args, **kwargs): # pragma: no cover
@@ -41,7 +40,7 @@ class Chemicals:
     ----------
     chemicals : Iterable[str or :class:`~thermosteam.Chemical`]
         Strings should be one of the following [-]:
-           * Name, in IUPAC form or common form or a synonym registered in PubChem
+           * Name, in IUPAC form or common form or an alias registered in PubChem
            * InChI name, prefixed by 'InChI=1S/' or 'InChI=1/'
            * InChI key, prefixed by 'InChIKey='
            * PubChem CID, prefixed by 'PubChem='
@@ -266,7 +265,7 @@ class CompiledChemicals(Chemicals):
     ----------
     chemicals : Iterable[str or Chemical]
            Strings should be one of the following [-]:
-              * Name, in IUPAC form or common form or a synonym registered in PubChem
+              * Name, in IUPAC form or common form or an alias registered in PubChem
               * InChI name, prefixed by 'InChI=1S/' or 'InChI=1/'
               * InChI key, prefixed by 'InChIKey='
               * PubChem CID, prefixed by 'PubChem='
@@ -347,10 +346,10 @@ class CompiledChemicals(Chemicals):
     def __dir__(self):
         return ('append', 'array', 'compile', 'extend', 
                 'get_combustion_reactions', 'get_index',
-                'get_lle_indices', 'get_synonyms',
+                'get_lle_indices', 'get_aliases',
                 'get_vle_indices', 'iarray', 'ikwarray',
                 'index', 'indices', 'kwarray', 'refresh_constants', 
-                'set_synonym') + self.IDs
+                'set_alias') + self.IDs
     
     def __reduce__(self):
         return CompiledChemicals, (self.tuple,)
@@ -549,7 +548,7 @@ class CompiledChemicals(Chemicals):
         all_names_list = []
         for i in chemicals:
             if not i.iupac_name: i.iupac_name = ()
-            all_names = set([*i.iupac_name, *i.synonyms, i.common_name, i.formula])
+            all_names = set([*i.iupac_name, *i.aliases, i.common_name, i.formula])
             all_names_list.append(all_names)
             for name in all_names:
                 if not name: continue
@@ -561,7 +560,7 @@ class CompiledChemicals(Chemicals):
             ID = i.ID
             for name in all_names:
                 if name and name not in repeated_names:
-                    self.set_synonym(ID, name)
+                    self.set_alias(ID, name)
         vle_chemicals = []
         lle_chemicals = []
         heavy_chemicals = []
@@ -619,9 +618,9 @@ class CompiledChemicals(Chemicals):
         formula_array.setflags(0)
         return formula_array
     
-    def get_parsable_synonym(self, ID):
+    def get_parsable_alias(self, ID):
         """
-        Return a synonym of the given chemical identifier that can be 
+        Return an alias of the given chemical identifier that can be 
         parsed by Python as a variable name
         
         Parameters
@@ -631,21 +630,23 @@ class CompiledChemicals(Chemicals):
             
         Examples
         --------
-        Get parsable synonym of 2,3-Butanediol:
+        Get parsable alias of 2,3-Butanediol:
         
         >>> from thermosteam import CompiledChemicals
         >>> chemicals = CompiledChemicals(['2,3-Butanediol'], cache=True)
-        >>> chemicals.get_parsable_synonym('2,3-Butanediol')
+        >>> chemicals.get_parsable_alias('2,3-Butanediol')
         'C4H10O2'
         
         """
         isvalid = utils.is_valid_ID      
-        for i in self.get_synonyms(ID):
+        for i in self.get_aliases(ID):
             if isvalid(i): return i        
     
-    def get_synonyms(self, ID):
+    get_parsable_synonym = get_parsable_alias
+    
+    def get_aliases(self, ID):
         """
-        Return all synonyms of a chemical.
+        Return all aliases of a chemical.
         
         Parameters
         ----------
@@ -654,55 +655,59 @@ class CompiledChemicals(Chemicals):
             
         Examples
         --------
-        Get all synonyms of water:
+        Get all aliases of water:
         
         >>> from thermosteam import CompiledChemicals
         >>> chemicals = CompiledChemicals(['Water'], cache=True)
-        >>> synonyms = chemicals.get_synonyms('Water')
-        >>> synonyms.sort()
-        >>> synonyms
+        >>> aliases = chemicals.get_aliases('Water')
+        >>> aliases.sort()
+        >>> aliases
         ['7732-18-5', 'H2O', 'Water', 'oxidane', 'water']
         
         """
         k = self._index[ID]
         return [i for i, j in self._index.items() if j==k] 
 
-    def set_synonym(self, ID, synonym):
+    get_synonyms = get_aliases
+
+    def set_alias(self, ID, alias):
         """
-        Set a new synonym for a chemical.
+        Set a new alias for a chemical.
         
         Parameters
         ----------
         ID : str
             Chemical identifier.
-        synonym : str
+        alias : str
             New identifier for chemical.
             
         Examples
         --------
-        Set new synonym for water:
+        Set new alias for water:
         
         >>> from thermosteam import CompiledChemicals
         >>> chemicals = CompiledChemicals(['Water', 'Ethanol'], cache=True)
-        >>> chemicals.set_synonym('Water', 'H2O')
+        >>> chemicals.set_alias('Water', 'H2O')
         >>> chemicals.H2O is chemicals.Water
         True
         
-        Note that you cannot use one synonym for two chemicals:
+        Note that you cannot use one alias for two chemicals:
         
-        >>> chemicals.set_synonym('Ethanol', 'H2O')
+        >>> chemicals.set_alias('Ethanol', 'H2O')
         Traceback (most recent call last):
-        ValueError: synonym 'H2O' already in use by Chemical('Water')
+        ValueError: alias 'H2O' already in use by Chemical('Water')
         
         """
         dct = self.__dict__
         chemical = dct[ID]
-        if synonym in dct and dct[synonym] is not chemical:
-            raise ValueError(f"synonym '{synonym}' already in use by {repr(dct[synonym])}")
+        if alias in dct and dct[alias] is not chemical:
+            raise ValueError(f"alias '{alias}' already in use by {repr(dct[alias])}")
         else:
-            self._index[synonym] = self._index[ID]
-            dct[synonym] = chemical
-        chemical.synonyms.add(synonym)
+            self._index[alias] = self._index[ID]
+            dct[alias] = chemical
+        chemical.aliases.add(alias)
+    
+    set_synonym = set_alias
     
     def zeros(self):
         """
