@@ -244,7 +244,7 @@ class Stream:
         '_bubble_point_cache', '_dew_point_cache',
         '_vle_cache', '_lle_cache', '_sle_cache',
         '_sink', '_source', '_price', '_islinked', '_property_cache_key',
-        '_property_cache', 'characterization_factors',
+        '_property_cache', 'characterization_factors', '_user_equilibrium',
         # '_velocity', '_height'
     )
     line = 'Stream'
@@ -303,6 +303,33 @@ class Stream:
         self.reset_cache()
         self._register(ID)
         self._islinked = False
+        self._user_equilibrium = None
+
+    def reset_flow(self, phase=None, units=None, total_flow=None, **chemical_flows):
+        """
+        Convinience method for resetting flow rate data.
+        
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'], cache=True)
+        >>> s1 = tmo.Stream('s1', Water=1)
+        >>> s1.reset_flow(Ethanol=1, phase='g', units='kg/hr', total_flow=2)
+        >>> s1.show('cwt')
+        Stream: s1
+         phase: 'g', T: 298.15 K, P: 101325 Pa
+         composition: Ethanol  1
+                      -------  2 kg/hr
+        
+        """
+        imol = self._imol
+        imol.empty()
+        if phase: imol.phase = phase
+        if chemical_flows:
+            keys, values = zip(*chemical_flows.items())
+            self.set_flow(values, units, keys)
+        if total_flow:
+            self.set_total_flow(total_flow, units)
 
     def _reset_thermo(self, thermo):
         if thermo is self._thermo: return
@@ -315,6 +342,16 @@ class Stream:
                 stream._imol = self._imol.get_phase(phase)
                 stream._thermo = thermo
 
+    def user_equilibrium(self, *args, **kwargs):
+        return self._user_equilibrium(self, *args, **kwargs)
+
+    def set_user_equilibrium(self, f):
+        self._user_equilibrium = f
+        
+    @property
+    def has_user_equilibrium(self):
+        return self._user_equilibrium is not None
+
     def get_CF(self, key, units=None):
         """
         Returns the life-cycle characterization factor on a kg basis given the
@@ -1667,6 +1704,7 @@ class Stream:
         if thermo and thermo.chemicals is not self.chemicals:
             new._imol.reset_chemicals(thermo.chemicals)
         new._thermal_condition = self._thermal_condition.copy()
+        new._user_equilibrium = self._user_equilibrium
         new.reset_cache()
         new.price = 0
         new.ID = ID
@@ -1703,6 +1741,7 @@ class Stream:
         new.reset_cache()
         new.characterization_factors = {}
         self._islinked = new._islinked = True
+        new._user_equilibrium = self._user_equilibrium
         return new
     
     def proxy(self, ID=None):
@@ -1740,6 +1779,7 @@ class Stream:
         new._property_cache_key = self._property_cache_key
         new._bubble_point_cache = self._bubble_point_cache
         new._dew_point_cache = self._dew_point_cache
+        new._user_equilibrium = self._user_equilibrium
         try: new._vle_cache = self._vle_cache
         except AttributeError: pass
         new.characterization_factors = {}
@@ -2002,9 +2042,9 @@ class Stream:
         if not z_sum: raise RuntimeError(f'{repr(self)} is empty')
         return z / z_sum
     
-    def get_molar_composition(self, IDs):
+    def get_molar_fraction(self, IDs):
         """
-        Return molar composition of given chemicals.
+        Return molar fraction of given chemicals.
 
         Parameters
         ----------
@@ -2016,7 +2056,7 @@ class Stream:
         >>> import thermosteam as tmo
         >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kmol/hr')
-        >>> s1.get_molar_composition(('Water', 'Ethanol'))
+        >>> s1.get_molar_fraction(('Water', 'Ethanol'))
         array([0.5 , 0.25])
 
         """
@@ -2024,9 +2064,11 @@ class Stream:
         if not F_mol: raise RuntimeError(f'{repr(self)} is empty')
         return self.imol[IDs] / F_mol
     
-    def get_mass_composition(self, IDs):
+    get_molar_composition = get_molar_fraction
+    
+    def get_mass_fraction(self, IDs):
         """
-        Return mass composition of given chemicals.
+        Return mass fraction of given chemicals.
 
         Parameters
         ----------
@@ -2038,7 +2080,7 @@ class Stream:
         >>> import thermosteam as tmo
         >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kg/hr')
-        >>> s1.get_mass_composition(('Water', 'Ethanol'))
+        >>> s1.get_mass_fraction(('Water', 'Ethanol'))
         array([0.5 , 0.25])
 
         """
@@ -2046,9 +2088,11 @@ class Stream:
         if not F_mass: raise RuntimeError(f'{repr(self)} is empty')
         return self.imass[IDs] / F_mass
     
-    def get_volumetric_composition(self, IDs):
+    get_mass_composition = get_mass_fraction
+    
+    def get_volumetric_fraction(self, IDs):
         """
-        Return volumetric composition of given chemicals.
+        Return volumetric fraction of given chemicals.
 
         Parameters
         ----------
@@ -2060,7 +2104,7 @@ class Stream:
         >>> import thermosteam as tmo
         >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'], cache=True) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
-        >>> s1.get_volumetric_composition(('Water', 'Ethanol'))
+        >>> s1.get_volumetric_fraction(('Water', 'Ethanol'))
         array([0.5 , 0.25])
 
         """
@@ -2068,6 +2112,8 @@ class Stream:
         if not F_vol: raise RuntimeError(f'{repr(self)} is empty')
         return self.ivol[IDs] / F_vol
     
+    get_volumetric_composition = get_volumetric_fraction
+    
     def get_concentration(self, IDs):
         """
         Return concentration of given chemicals in kmol/m3.
@@ -2096,7 +2142,7 @@ class Stream:
         chemicals = self.vle_chemicals
         F_l = eq.LiquidFugacities(chemicals, self.thermo)
         IDs = tuple([i.ID for i in chemicals])
-        x = self.get_molar_composition(IDs)
+        x = self.get_molar_fraction(IDs)
         if x.sum() < 1e-12: return 0
         return F_l(x, self.T).sum()
     
@@ -2147,7 +2193,7 @@ class Stream:
         chemicals = ms.vle_chemicals
         F_l = eq.LiquidFugacities(chemicals, ms.thermo)
         IDs = tuple([i.ID for i in chemicals])
-        x = other.get_molar_composition(IDs)
+        x = other.get_molar_fraction(IDs)
         T = ms.T
         P = ms.P
         vapor = ms['g']
